==> glpi_0.80.7.orig.tar.gz: glpi/scripts/softcat_mass_compute.php <==
<?php


/*
 * @version $Id: softcat_mass_compute.php 17154 2012-01-24 11:27:36Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Julien Dombre
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

// COMPUTER ONLY UNDEF CATEGORIES
$ONLY_UNDEFINED = true;


$softcatrule = new RuleSoftwareCategoryCollection;
$soft        = new Software;

$query = "SELECT `id`, `softwarecategories_id`
          FROM `glpi_softwares`";

if ($result=$DB->query($query)) {
   if ($DB->numrows($result)>0) {
      while ($data=$DB->fetch_array($result)) {
         if (!$ONLY_UNDEFINED || $data['softwarecategories_id']==0) {
            $params = array();

            //Get software name and manufacturer
            $soft->getFromDB($data['id']);
            $params["name"]             = $soft->fields["name"];
            $params["manufacturers_id"] = $soft->fields["manufacturers_id"];

            //Process rules
            $soft->update($softcatrule->processAllRules(null, $soft->fields, $params));
         }
      }
   }
}
?>

==> glpi_0.83.31.orig.tar.gz: glpi/scripts/softcat_mass_compute.php <==
<?php


/*
 * @version $Id: softcat_mass_compute.php 17152 2012-01-24 11:22:16Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Julien Dombre
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

// COMPUTER ONLY UNDEF CATEGORIES
$ONLY_UNDEFINED = true;


$softcatrule = new RuleSoftwareCategoryCollection();
$soft        = new Software();

$query = "SELECT `id`, `softwarecategories_id`
          FROM `glpi_softwares`";

if ($result=$DB->query($query)) {
   if ($DB->numrows($result)>0) {
      while ($data=$DB->fetch_array($result)) {
         if (!$ONLY_UNDEFINED || $data['softwarecategories_id']==0) {
            $params = array();

            //Get software name and manufacturer
            $soft->getFromDB($data['id']);
            $params["name"]             = $soft->fields["name"];
            $params["manufacturers_id"] = $soft->fields["manufacturers_id"];

            //Process rules
            $soft->update($softcatrule->processAllRules(null, $soft->fields, $params));
         }
      }
   }
}
?>
